package FFRIndexed::Plugin;
use strict;
use Carp qw(croak);
use base 'Class::Data::Inheritable';
use Table::Denormalized;
use Data::Dumper;
use vars qw($VERSION);
$VERSION = '0.06';

__PACKAGE__->mk_classdata('columnset', undef);
__PACKAGE__->mk_classdata('columncode', undef );
__PACKAGE__->mk_classdata('stale_columns', undef);

sub new {
  my $class = shift;
  bless {}, $class;
};

sub scan {
  my ($self,$file,$knowledge) = @_;

  my %columns = %{ $self->columncode };

  for my $col (sort keys %columns) {
    my $code = $columns{$col};
    if (! exists $knowledge->{$col}) {
      my @val = $code->($self,$file,$knowledge);
      # Do not optimize this, because $code has side effects!!
      $knowledge->{$col} ||= $val[0]
        if @val;
    };
  };

  $knowledge
};

sub stale {
  my ($self,$file,$cached_knowledge) = @_;

  my %columns = %{ $self->columncode };
  my $columns = $self->stale_columns;
  my @columns = $columns ? @$columns : sort keys %columns;

  my $current_knowledge = {};

  for my $col (@columns) {
    my $code = $columns{$col};
    return (1,$col)
      if  ! exists $cached_knowledge->{$col};
    if (! exists $current_knowledge->{$col}) {
      my @val = $code->($self,$file,$current_knowledge);
      # $code may have side effects!!

      if (! exists $current_knowledge->{$col} and @val) {
        $current_knowledge->{$col} = $val[0];
      };
    };
    my $current = $current_knowledge->{$col};

    return (1,$col,$current)
      if ($current ||'') ne ($cached_knowledge->{$col} || '');
  };

  return;
};

package IO::Handle::Lazy;
use strict;
use IO::Handle;
use base 'Class::Accessor';

__PACKAGE__->mk_accessors(qw{name});

sub new {
  my ($class,$filename) = @_;
  my $self = { name => $filename, fh => undef };
  bless $self, $class;
  $self
};

sub fh {
  my $self = shift;
  $self->{fh} ||= do {
    my $fh;
    open $fh, "<", URI::file->new( $self->name )->file
      or $fh = undef;
      #or die sprintf "Couldn't open %s : %s", $self->name, $!;
    $fh
  };
  $self->{fh};
};

1;
