package FFRIndexed::Plugin::File;
use strict;
use base 'FFRIndexed::Plugin';
use URI;
use Digest::MD5;
use Data::Dumper;
use vars qw($VERSION);
$VERSION = '0.06';

__PACKAGE__->columnset(
  Table::Denormalized::ColumnSet->new(
    uri      => 'VARCHAR(1024)',
    size     => 'INTEGER',
    modified => 'INTEGER',
    md5      => 'VARCHAR(64)',
  )
);

__PACKAGE__->columncode({
  uri      => \&find_file,
  size     => \&stat_file,
  modified => \&stat_file,
  md5      => \&get_md5,
});

__PACKAGE__->stale_columns([qw[ uri size modified ]]);

sub find_file {
  my $u = URI::file->new( $_[1]->name );
  if (-f $u->file) {
    return "$u"
  } else {
    return undef
  };
};

sub stat_file {
  my ($self,$file,$knowledge) = @_;

  my @info = stat $file->fh;

  @{$knowledge}{qw(size modified)} = @info[7,9];
};

sub get_md5 {
  my ($self,$file,$knowledge) = @_;
  my $fh = $file->fh;

  if ($fh) {
    seek $fh, 0,0;
    my $digest = Digest::MD5->new();
    $digest->addfile($fh);

    return $digest->b64digest
  } else {
    return
  };
};

1;
