package FFRIndexed::Plugin::Image;
use strict;
use base 'FFRIndexed::Plugin';
use Data::Dumper;
use Image::Info qw(image_info dim);
use vars qw($VERSION);
$VERSION = '0.06';

=head1 NAME

FFRIndexed::Plugin::Image - extract (JPEG) image information

=head1 ABSTRACT

This plugin extracts information about image files.

=cut


__PACKAGE__->columnset(
  Table::Denormalized::ColumnSet->new(
    mime_type => 'VARCHAR(64)',
    width     => 'INTEGER',
    height    => 'INTEGER',
    file_ext  => 'VARCHAR(64)',
    comment   => 'VARCHAR(1024)',
  )
);

__PACKAGE__->columncode({
    width     => \&get_dimensions,
    height    => \&get_dimensions,
    file_ext  => \&get_dimensions,
    mime_type => \&get_dimensions,
    comment   => \&get_dimensions,
    file_ext  => \&get_dimensions,
});

__PACKAGE__->stale_columns([qw[ width height ]]);

sub get_dimensions {
  my ($self,$file,$knowledge) = @_;
  my $obj = image_info($file->name);

  if (! exists $obj->{error}) {
    $knowledge->{mime_type} ||= $obj->{file_media_type};
    $knowledge->{comment} ||= ref $obj->{Comment} ? join "", @{ $obj->{Comment} } : $obj->{Comment};

    my @res = dim($obj);

    @{$knowledge}{qw(width height)} = @res;
  };

  return
};

1;
