package FFRIndexed::Plugin::MP3;
use strict;
use base 'FFRIndexed::Plugin';
use URI;
use MP3::Info;
use MP3::Tag;
use Data::Dumper;
use vars qw($VERSION);
$VERSION = '0.06';

=head1 NAME

FFRIndexed::Plugin::MP3 - extract MP3 information

=head1 ABSTRACT

This plugin extracts information about mp3 files.

=cut

__PACKAGE__->columnset(
  Table::Denormalized::ColumnSet->new(
    artist   => 'VARCHAR(1024)',
    album    => 'VARCHAR(1024)',
    comment  => 'VARCHAR(1024)',
    genre    => 'VARCHAR(1024)',
    title    => 'VARCHAR(1024)',
    year     => 'INTEGER', # YYYY
    track    => 'INTEGER', # 1 based
    length   => 'INTEGER', # in seconds
  )
);

__PACKAGE__->columncode({
    artist   => \&stat_file,
    album    => \&stat_file,
    comment  => \&stat_file,
    genre    => \&stat_file,
    title    => \&stat_file,
    year     => \&stat_file,
    track    => \&stat_file,
    length   => \&get_length,
});

__PACKAGE__->stale_columns([qw[]]);

sub stat_file {
  my ($self,$file,$knowledge) = @_;
  my $info = MP3::Tag->new($file->name);

  # get some information about the file in the easiest way
  @{$knowledge}{qw(title track artist album comment year genre)} = $info->autoinfo();

  if (defined $knowledge->{track} && $knowledge->{track} ne '') {
    if ($knowledge->{track} =~ m!^(\d+)[^\d]!) {
      $knowledge->{track} = $1;
    };
    $knowledge->{track} = $knowledge->{track} + 0
  };

  return
};

sub get_length {
  my ($self,$file,$knowledge) = @_;

  my $info = get_mp3info($file->name);
  return unless $info;

  $knowledge->{length} = $info->{MM} * 60 + $info->{SS};
};

1;
