package FFRIndexed::Plugin::MSOProperty;
use strict;
use base 'FFRIndexed::Plugin';
use URI;
use Data::Dumper;
use OLE::Storage;
use OLE::PropertySet;
use vars qw($VERSION %column_map);
$VERSION = '0.06';

=head1 NAME

FFRIndexed::Plugin::MSOProperty - extract MS Office Document properties

=head1 ABSTRACT

This is a quick hack using L<OLE::Storage> to extract
some document properties from MS Office documents. Currently,
the following five properties are extracted:

=head2 DEFAULT PROPERTIES

  comment
  title
  keywords
  author

=head2 CUSTOM PROPERTIES

  ablage
  
There is no mechanism yet to add more custom properties
or to autodiscover new custom properties. Hack the source,
Luke.

=cut

__PACKAGE__->columnset(
  Table::Denormalized::ColumnSet->new(
    comment  => 'VARCHAR(1024)',
    title    => 'VARCHAR(1024)',
    keywords => 'VARCHAR(1024)',
    author   => 'VARCHAR(1024)',
    ablage   => 'VARCHAR(1024)',
  )
);

__PACKAGE__->columncode({
    comment  => \&stat_file,
    title    => \&stat_file,
    keywords => \&stat_file,
    author   => \&stat_file,
    ablage   => \&stat_file,
});

__PACKAGE__->stale_columns([qw[]]);

%column_map = (
    Title    => 'title',
    Comments => 'comment',
    Authress => 'author',
    Keywords => 'keywords',
    Ablage   => 'ablage',
);

sub stat_file {
  my ($self,$file,$knowledge) = @_;

  my @columns = values %column_map;
  my %props = get_properties($file);
  use Data::Dumper;
  #warn Dumper \%props;
  #warn Dumper [ @props{keys %column_map} ];
  #warn Dumper [ values %column_map ];

  # get some information about the file in the easiest way
  @{$knowledge}{values %column_map} = @props{keys %column_map};

  #warn $knowledge->{uri};
  #warn "$_:\t$knowledge->{$_}" for @columns;

  return $knowledge
};

my @properties = (
    "\05SummaryInformation",
    "\05DocumentSummaryInformation",
);
sub get_properties {
    my ($file) = @_;

    my %Directory;

    my $Var = OLE::Storage->NewVar();
    my $Doc = OLE::Storage->open(undef, $Var, $file->name);

    # If there was some kind of error, skip reading
    return
        if ! $Doc;

    $Doc->directory(0, \%Directory, 'string')
        or die sprintf "Couldn't read root directory of '%s'", $file->name;

    return map { extract_properties($Directory{$_}, $Var,$Doc) } @properties;
};

sub extract_properties {
    my ($handle,$Var,$Doc) = @_;
    my $PPS = OLE::PropertySet->load(undef,$Var,$handle,$Doc);
    $PPS->idset( \my %idset, );

    my @result;

    for (sort { $a <=> $b } keys %idset) {
        my $name = "Unknown ($_)";
        $name = $idset{$_} || $name;

        my $idx = $_;
        if ($_ > 4096) {
            $idx++; # ugly hack
        };
        my $value = $PPS->property($idx)->string;

        push @result, $name, $value;
    };
    @result;
};

1;
