package FFRIndexed::Plugin::MimeType;
use strict;
use base 'FFRIndexed::Plugin';
use URI;
#use Digest::MD5;
#use Data::Dumper;
use MIME::Types;
use File::MMagic;
use vars qw($VERSION);
$VERSION = '0.06';

=head1 NAME

FFRIndexed::Plugin::MimeType - extract the MIME type

=head1 ABSTRACT

This plugin determins the MIME type for files using
L<MIME::Types> and L<File::MMagic>.

=cut

__PACKAGE__->columnset(
  Table::Denormalized::ColumnSet->new(
    mime_type => 'VARCHAR(64)',
  )
);

__PACKAGE__->columncode({
    mime_type => \&get_mime_type,
});

__PACKAGE__->stale_columns([qw[ mime_type ]]);

my $mime = MIME::Types->new();
my $magic = File::MMagic->new();

sub get_mime_type {
  my ($self,$file,$knowledge) = @_;
  my $obj = $mime->mimeTypeOf($file->name);

  #warn "Get_mime_type()";
  #warn $file->name;
  #warn \$knowledge;

  $knowledge->{mime_type} = ($obj
                             ? $obj->type
                             : $magic->checktype_filehandle($file->fh));
};

1;
