#!/usr/bin/perl -w
use strict;
use Test::More tests => 9;
use DBI;

use_ok 'Table::Denormalized';

my $dbfile = "$0.sqlite";
if (-f $dbfile) {
  unlink $dbfile or
    warn "Couldn't remove '$dbfile': $!";
};

END {
  if (-f $dbfile) {
    unlink $dbfile or
      warn "Couldn't remove '$dbfile': $!";
  };
};

my $table = Table::Denormalized->new( dsn => "dbi:SQLite:dbname=$dbfile", table => 'file_cache' );
ok $table->create, "Can create fresh table";

$table->add_set(Table::Denormalized::ColumnSet->new(
  _name   => 'filesystem properties',
  uri     => 'VARCHAR(2048)', # the uri which is queried for
  md5     => 'VARCHAR(32)',
  size    => 'INTEGER',
  created => 'INTEGER', # epoch seconds instead of DATE because of SQLite
));

my @names = map { $_->name } $table->columns;
is_deeply \@names, [qw(created md5 size uri )], "Added the correct names";

@names = map { $_->name } $table->missing_columns;
is_deeply \@names, [qw(created md5 size uri )], "The database is missing the correct names";

my @st = $table->alter_sql;

ok $table->alter_table, "Altered the table OK"
  or diag join "\n", @st;

$table->add_set(Table::Denormalized::ColumnSet->new(
  _name   => 'media properties',
  length  => 'INTEGER', # the play length in seconds
  artist  => 'VARCHAR(1024)',
  title   => 'VARCHAR(1024)',
  album   => 'VARCHAR(1024)',
  year    => 'INTEGER', # YYYY
  track   => 'INTEGER', # order in the album/collection
));

@names = map { $_->name } $table->columns;
is_deeply \@names, [qw(album artist created length md5 size title track uri year)], "Added the correct names";

@names = map { $_->name } $table->missing_columns;
is_deeply \@names, [qw(album artist length title track year)], "The database is missing the correct names";

@st = $table->alter_sql;

$table->alter_table;
@names = map { $_->name } $table->missing_columns;
is_deeply \@names, [], "The database now has the correct names"
  or diag join "\n", @st;

is_deeply [ $table->alter_sql ], [], "No changes are necessary if there are no missing columns";