#!/usr/bin/perl -wT
use strict;
use Test::More tests => 21;

use_ok 'CGI::PersistentParams';

my $q = CGI::PersistentParams->new();
$q->param( template => 'foo' );
$q->param( page => 1 );

is $q->link(), "template=foo;page=1", "template=foo;page=1";
is $q->hidden(), 
   qq{<input type="hidden" name="template" value="foo" />\n<input type="hidden" name="page" value="1" />\n}, 
   "hidden too";

is $q->link( { template => 'bar' } ), "template=bar;page=1", "template=bar;page=1";
is $q->hidden({ template => 'bar' }), 
   qq{<input type="hidden" name="template" value="bar" />\n<input type="hidden" name="page" value="1" />\n}, 
   "hidden too";

is $q->link( { page => 2 } ),  "template=foo;page=2", "template=foo;page=2";
is $q->hidden({ page => 2 }),
   qq{<input type="hidden" name="template" value="foo" />\n<input type="hidden" name="page" value="2" />\n}, 
   "hidden too";

$q->discard(['template']);
is $q->link(), "page=1", "page=1";
is $q->hidden(),
   qq{<input type="hidden" name="page" value="1" />\n}, 
   "hidden too";

is $q->link( { template => 'bar' } ), "template=bar;page=1", "template=bar;page=1";
is $q->hidden({ template => 'bar' }), 
   qq{<input type="hidden" name="template" value="bar" />\n<input type="hidden" name="page" value="1" />\n}, 
   "hidden too";

is $q->link( { page => 2 } ),  "page=2", "page=2";
is $q->hidden({ page => 2 }), 
   qq{<input type="hidden" name="page" value="2" />\n}, 
   "hidden too";

my %defaults = (
    template => 'foo',
    page     => 1,
);

is $q->link({},\%defaults), "", "All defaults results in an empty query string";
is $q->hidden({},\%defaults), 
   qq{}, 
   "hidden too";

is $q->link({page => 2},\%defaults), "page=2", "All defaults results in an empty query string";
is $q->hidden({page => 2},\%defaults), 
   qq{<input type="hidden" name="page" value="2" />\n}, 
   "hidden too";

is $q->link({page => 2, template => 'bar'},\%defaults), "template=bar;page=2", "All defaults results in an empty query string";
is $q->hidden({page => 2, template => 'bar'},\%defaults), 
   qq{<input type="hidden" name="template" value="bar" />\n<input type="hidden" name="page" value="2" />\n}, 
   "hidden too";

is $q->link({user => 'anonymous'},\%defaults), "user=anonymous", "Unrelated param gets passed through";
is $q->hidden({user => 'anonymous'},\%defaults), 
   qq{<input type="hidden" name="user" value="anonymous" />\n}, 
   "hidden too";
