#!/usr/bin/perl -w
use strict;
use Test::More tests => 7;
use Data::Dumper qw(Dumper);
use FFRIndexed;
use Template;
use lib 'inc';
use TableLoader;

$|++;
use_ok 'FFRIndexed::Template';

my $table = create_and_load("test",\*DATA);
my $idx = FFRIndexed->new( create_if_needed => 1, table => 'test', verbose => 0 );

my $file_count = 7;
my $all_files = $idx->all;
is scalar @$all_files, $file_count, "We found all files.";

my $templater = FFRIndexed::Template->new(
                 query => [], 
                 columns => [qw[artist album mime_type]],
                 index => $idx,
                 explicit_columns => [],
                );
isa_ok $templater, 'FFRIndexed::Template';

my @refinements = $templater->refining_columns;
is_deeply( \@refinements, [qw[artist album mime_type]], "We get three possible refinements");

my @old_size = $templater->current_content;
is scalar @old_size, $file_count, "We got $file_count tracks";

my $template = Template->new({ INCLUDE_PATH => 'templates/', DEBUG => 1 });
SKIP: {
    isa_ok( $template, 'Template' )
        or skip "Did not get a valid template instance",1;

    ok $template->process( 'query.template', { query => $templater }, \my $output ), "The template runs OK";
    if (! $output) {
        diag $template->error;
    };
};

__DATA__
uri:VARCHAR(20),mime_type:VARCHAR(32),artist:VARCHAR(32),album:VARCHAR(32)
foo1.mp3,audio/mpeg,Jamiroquai,Dynamite
foo2.mp3,audio/mpeg,Jamiroquai,Dynamite
front.jpg,image/jpeg,Jamiroquai,Dynamite
back.jpg,image/jpeg,Jamiroquai,Dynamite
bar1.mp3,audio/mpeg,Pet Shop Boys,Please
bar2.mp3,audio/mpeg,Pet Shop Boys,Please
baz.mp3,audio/mpeg,Pet Shop Boys,Please
