#!/usr/bin/perl -w
use strict;
use Data::Dumper;
use Test::More tests => 4;

use_ok 'FFRIndexed';

my $dbfile = "$0.sqlite";

if (-f $dbfile) {
    diag "Removing leftover test database '$dbfile'";
    unlink $dbfile
        or diag "Couldn't remove $dbfile: $!";
};

my $idx = FFRIndexed->new( create => 1);

opendir my $dh, 't'
    or die "Couldn't read 't': $!";
my @entries = grep { -f } map { "t/$_" } readdir $dh;
closedir $dh;
$idx->scan($_) for @entries;

END { 
    undef $idx; 
    unlink $dbfile
        or diag "Couldn't remove $dbfile: $!";
}

my $res = $idx->all();
is @$res, 25, "We found twenty-five files total";

my @stale = map { my @cols = $_->stale; @cols ? [ $_, @cols ] : () } @$res;

(my $sqlite) = grep { $_->[0]->{uri} =~ /\bno_stale_files.t.sqlite$/i} @stale;
$sqlite = $sqlite->[0];
isa_ok $sqlite, 'FFRIndexed::File';

@stale = grep { ! $_->[0]->{uri} =~ /\bno_stale_files.t.sqlite$/i} @stale;

is( (scalar @stale), 0, "No other stale files in the freshly scanned database")
  or do {
    for (@stale) {
      my ($entry, @cols) = @$_;
      diag $entry;
      for (@cols) {
        diag join "\t", @{$_}{qw{column stale_value new_value}};
      };
    };
  };
