#!/usr/bin/perl -w
use strict;
use Test::More tests => 4+6;
use Data::Dumper qw(Dumper);
use FFRIndexed;
use lib 'inc';
use TableLoader;

$|++;
use_ok 'FFRIndexed::Template';

my $table = create_and_load("test",\*DATA);
my $idx = FFRIndexed->new( create_if_needed => 1, table => $table );

my $file_count = 7;
my $all_files = $idx->all;

my $templater = FFRIndexed::Template->new(
                 query => [], 
                 columns => [qw[artist album mime_type title]],
                 index => $idx,
                 explicit_columns => [],
);
isa_ok $templater, 'FFRIndexed::Template';

my @refinements = $templater->refining_columns;
is_deeply( \@refinements, [qw[artist album mime_type]], "We get three possible refinements");

my @content = $templater->current_content;
is scalar @content, $file_count, "We got $file_count tracks";

for my $refinement (@refinements) {
  for my $val (@{$refinement->values}) {
    cmp_ok $val->{count}, '>', 0, "$refinement:$val has more than 0 entries (" . $val->{count} . ")";
  };
};

__DATA__
uri:VARCHAR(20),mime_type:VARCHAR(32),artist:VARCHAR(32),album:VARCHAR(32),title:VARCHAR(32)
foo1.mp3,audio/mpeg,Jamiroquai,Dynamite,same
foo2.mp3,audio/mpeg,Jamiroquai,Dynamite,same
front.jpg,image/jpeg,Jamiroquai,Dynamite,same
back.jpg,image/jpeg,Jamiroquai,Dynamite,same
bar1.mp3,audio/mpeg,Pet Shop Boys,Please,same
bar2.mp3,audio/mpeg,Pet Shop Boys,Please,same
baz.mp3,audio/mpeg,Pet Shop Boys,Please,same
